Module raw

Module raw 

Raw (contiguous) memory dump format provider.

The simplest possible format: a flat byte array representing contiguous physical memory starting at address 0.

Structs

RawPlugin
FormatPlugin implementation for raw (flat) dumps.
RawProvider
Provider that exposes physical memory from a raw (flat) dump.