RawProvider

Struct RawProvider 

pub struct RawProvider { /* private fields */ }
Provider that exposes physical memory from a raw (flat) dump.

The entire file is treated as a single range [0, data.len()).

Implementations

Source

impl RawProvider

pub fn from_bytes(bytes: &[u8]) -> Self

Construct a RawProvider from an in-memory byte slice (infallible).

pub fn from_path(path: &Path) -> Result<Self>

Construct a RawProvider by reading a file from the given path.