Physical memory dump format parsers.
Modules
- avml
- AVML v2 dump format provider.
- elf_
core - ELF core dump format provider.
- hiberfil
- Windows hibernation file (
hiberfil.sys) format provider. - kdump
- Kdump (makedumpfile / diskdump) format provider.
- lime
- LiME (Linux Memory Extractor) dump format provider.
- raw
- Raw (contiguous) memory dump format provider.
- test_
builders - Synthetic dump builders for unit tests.
- vmware
- VMware
.vmss/.vmsnstate file format provider. - win_
crashdump - Windows crash dump (
.dmp) format provider.
Structs
- Dump
Metadata - Optional metadata extracted from dump file headers.
- Physical
Range - A contiguous range of physical memory present in the dump.
Enums
- Error
- Error type for memf-format operations.
- Machine
Type - Machine architecture identified from a dump header.
Traits
- Format
Plugin - A plugin that can detect and open a specific dump format.
- Physical
Memory Provider - A provider of physical memory from a dump file.
Functions
- open_
dump - Open a dump file by probing all registered format plugins.
- open_
dump_ with_ raw_ fallback - Like
open_dump, but accepts the raw format as a last resort.
Type Aliases
- Result
- A Result alias for memf-format.