pub struct RawProvider { /* private fields */ }Expand description
Provider that exposes physical memory from a raw (flat) dump.
The entire file is treated as a single range [0, data.len()).
Implementations
Sourceimpl RawProvider
impl RawProvider